@@ -1,14 +1,20 @@
-from dodo_commands.framework.command_error import CommandError
 import os
 import re
 import sys
 
+from dodo_commands.framework.command_error import CommandError
+from dodo_commands.framework.util import EnvironMemo
+
 
 class KeyNotFound(CommandError):
     """Raised if an xpath is not found in a configuration."""
     pass
 
 
+def _xpath_to_string(xpath):
+    return '/' + '/'.join([str(x) for x in xpath])
+
+
 class DictKey:
     def __init__(self, the_dict, the_key, xpath):
         self.dict = the_dict
@@ -19,8 +25,8 @@ class DictKey:
         return "DK[%s]" % self.key
 
     def warning_msg_not_expanded(self):
-        return "Unexpanded key {key} at location /{xpath}".format(
-            key=self.key, xpath='/'.join([str(x) for x in self.xpath]))
+        return "Unexpanded key {key} at location {xpath}".format(
+            key=self.key, xpath=_xpath_to_string(self.xpath))
 
     def create_dict_val(self, expanded_key):  # noqa
         if expanded_key != self.key:
@@ -41,15 +47,9 @@ class DictVal:
     def replace_value(self, new_value):
         self.dict[self.key] = new_value
 
-    def must_eval(self):
-        return (isinstance(self.xpath[-1], str) and
-                self.xpath[-1].endswith('_EVAL') or
-                (len(self.xpath) >= 2 and isinstance(self.xpath[-2], str) and
-                 self.xpath[-2].endswith('_EVAL')))
-
     def warning_msg_not_expanded(self):
-        return "Unexpanded value {val} at location /{xpath}".format(
-            val=self.get_value(), xpath='/'.join([str(x) for x in self.xpath]))
+        return "Unexpanded value {val} at location {xpath}".format(
+            val=self.get_value(), xpath=_xpath_to_string(self.xpath))
 
     def __repr__(self):  # noqa
         return "DV[%s]" % self.key
@@ -67,13 +67,9 @@ class ListVal:
     def replace_value(self, new_value):
         self.list[self.idx] = new_value
 
-    def must_eval(self):
-        return (len(self.xpath) >= 2 and isinstance(self.xpath[-2], str) and
-                self.xpath[-2].endswith('_EVAL'))
-
     def warning_msg_not_expanded(self):
-        return "Unexpanded value {val} at location /{xpath}".format(
-            val=self.get_value(), xpath='/'.join([str(x) for x in self.xpath]))
+        return "Unexpanded value {val} at location {xpath}".format(
+            val=self.get_value(), xpath=_xpath_to_string(self.xpath))
 
     def __repr__(self):  # noqa
         return "L[%s]" % self.idx
@@ -81,11 +77,15 @@ class ListVal:
 
 class Key:
     """Access a nested value in a dict."""
-
-    def __init__(self, config, xpath):  # noqa
+    def __init__(self, config, xpath_or_str):  # noqa
         self.config = config
+
+        def split_on_slash(key):
+            return [k for k in key[1:].split("/") if k]
+
         # the list of sub-keys along the path to an item in self.config
-        self.xpath = xpath
+        self.xpath = split_on_slash(xpath_or_str) if isinstance(
+            xpath_or_str, str) else xpath_or_str
 
     def child(self, subkey):
         """Return key for child with subkey."""
@@ -131,7 +131,7 @@ class Key:
         del node[self.xpath[-1]]
 
     def __repr__(self):  # noqa
-        return "/" + "/".join([str(x) for x in self.xpath])
+        return _xpath_to_string(self.xpath)
 
 
 class ConfigExpander:
@@ -139,9 +139,9 @@ class ConfigExpander:
 
     _key_regexp = r"\$\{(/[^\}]*)\}"
 
-    @classmethod
-    def _get_xpath_from_string(cls, xpath_string):
-        return tuple([ix for ix in xpath_string.split("/") if ix])
+    def __init__(self, extra_vars=None, warn=True):
+        self.extra_vars = extra_vars or {}
+        self.warn = warn
 
     def _expand_str(self, current_str):
         expanded_str = current_str
@@ -154,13 +154,12 @@ class ConfigExpander:
             changed = False
             for key_expression in reversed(key_expressions):
                 xpath_string = key_expression.group(1)
-                xpath = self._get_xpath_from_string(xpath_string)
 
-                key = Key(self.config, xpath)
+                key = Key(self.config, xpath_string)
                 if key.exists():
-                    expanded_str = (
-                        expanded_str[:key_expression.start()] + str(key.get())
-                        + expanded_str[key_expression.end():])
+                    expanded_str = (expanded_str[:key_expression.start()] +
+                                    str(key.get()) +
+                                    expanded_str[key_expression.end():])
 
                     if expanded_str not in known_strs:
                         known_strs.append(expanded_str)
@@ -174,7 +173,14 @@ class ConfigExpander:
                 x for x in re.finditer(self._key_regexp, current_str)
             ]
 
-        return os.path.expandvars(expanded_str)
+        with EnvironMemo(self.extra_vars):
+            expanded_str = os.path.expandvars(expanded_str)
+
+        env_key_regexp = r"\$\{([^\}]*)\}"
+        env_key_expressions = [
+            x for x in re.finditer(env_key_regexp, expanded_str)
+        ]
+        return expanded_str if not env_key_expressions else None
 
     def _expand(self, raw_obj):
         if isinstance(raw_obj, str):
@@ -201,15 +207,7 @@ class ConfigExpander:
                 todo.append(ListVal(obj, idx, xpath + [idx]))
             return True
 
-    def _eval(self, value, xpath):
-        try:
-            return eval(value)
-        except:
-            raise CommandError(
-                "Cannot evaluate {value} at location {xpath}".format(
-                    value=value, xpath=xpath))
-
-    def run(self, config):  # noqa
+    def run(self, config, callbacks=None):  # noqa
         nodes = []
         self.config = config
         self._schedule_children(config, nodes, [])
@@ -236,12 +234,18 @@ class ConfigExpander:
                             new_nodes.append(node)
                         else:
                             changed = True
-                            node.replace_value(
-                                self._eval(expanded_value, node.xpath)
-                                if node.must_eval() else expanded_value)
+
+                            node.replace_value(expanded_value)
+                            if _xpath_to_string(node.xpath) in (callbacks
+                                                                or {}):
+                                callbacks[_xpath_to_string(
+                                    node.xpath)](expanded_value)
                 else:
                     raise CommandError("Should not reach here")
+
             nodes = new_nodes
 
-        for node in nodes:
-            sys.stderr.write("Warning: %s\n" % node.warning_msg_not_expanded())
+        if self.warn:
+            for node in nodes:
+                sys.stderr.write("Warning: %s\n" %
+                                 node.warning_msg_not_expanded())
